@@ -1,9 +1,9 @@
-use anyhow::{bail, Context, Result};
-
 use std::fmt::{self, Display, Formatter};
 use std::io;
 
-// Custom error type for early exit.
+use anyhow::{bail, Context, Result};
+
+/// Custom error type for early exit.
 #[derive(Debug)]
 pub struct SilentExit {
     pub code: i32,
@@ -15,12 +15,12 @@ impl Display for SilentExit {
     }
 }
 
-pub trait WriteErrorHandler {
-    fn wrap_write(self, device: &str) -> Result<()>;
+pub trait BrokenPipeHandler {
+    fn pipe_exit(self, device: &str) -> Result<()>;
 }
 
-impl WriteErrorHandler for io::Result<()> {
-    fn wrap_write(self, device: &str) -> Result<()> {
+impl BrokenPipeHandler for io::Result<()> {
+    fn pipe_exit(self, device: &str) -> Result<()> {
         match self {
             Err(e) if e.kind() == io::ErrorKind::BrokenPipe => bail!(SilentExit { code: 0 }),
             result => result.with_context(|| format!("could not write to {}", device)),
